;;; This file is part of guile-with-graphics, a graphic library for Guile

;;; Copyright (C) 2009  Luca Saiu

;;; This program is free software: you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation, either version 3 of the License, or
;;; (at your option) any later version.

;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.

;;; You should have received a copy of the GNU General Public License
;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.


(initialize-graphics "Console demo" 800 600)

(load "../color.scm") ;; this must be loaded *after* graphics is initialized
(load "../utility.scm")
(load "../graphics.scm")
(load "../interactive.scm")

(set! console-background-color (dark blue))

(define (handle-event event)
  (cond ((quit-event? event)
         (exit 0))
        (else
         ;; Show all events on the console:
         (console-write-line! (s-expression->string event)))))

(define (on-tick seconds-since-last-call)
  ;; Handle all enqueued events:
  (handle-all-enqueued-events handle-event)
  ;; Clear the window:
  (clear black)
  
  ;; If we had something interesting (besides the console) to draw on the
  ;; window we could draw it here.
  (draw-centered-text "Move the mouse over this window, push the buttons and some"
                      (/ (window-width) 2)
                      50
                      white)
  (draw-centered-text "keyboard keys; then try not to touch anything for some seconds,"
                      (/ (window-width) 2)
                      70
                      white)
  (draw-centered-text "and see what happens."
                      (/ (window-width) 2)
                      90
                      white)
  
  ;; You just have to draw the console:
  (console-draw)
  ;; Refresh, and we're done. We just have to call console-write-line! to
  ;; add lines to the console, and our nice scrolling effects are
  ;; automatically supported.
  (refresh))

(call-with-maximum-frequency 50
                             on-tick)
