/* This file is part of guile-with-graphics, a graphic library for Guile

Copyright (C) 2008, 2009  Luca Saiu
Based on turtle, by Luca Saiu

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>. */


#ifndef COLOR_H_
#define COLOR_H_

#include <SDL.h>
#include <libguile.h>

/* A color is defined by the three RGB components, expressed
   as floats, in the interval [0.0, 1.0].
   The data structure defined here is intentionally redundant: we
   *also* store the same information as internally used by SDL, both
   as unsigned bytes and a single 32-bit quantity. If not many colors
   are needed, it may be more efficient to create them once and for
   all with all the conversions pre-computed, and then simply re-use
   these "fat" structures: */
struct game_color{
  /* Our "native" format: */
  float red;
  float green;
  float blue;
  
  /* SDL format: three bytes: */
  Uint8 red_as_uint8, green_as_uint8, blue_as_uint8;
  
  /* SDL format: 32-bit: */
  Uint32 color_as_uint32;
}; // struct

/* We always refer to a color using a pointer: */
typedef struct game_color* game_color_t;

/* Fill the fields used for SDL formats in the given color, converting
   the float coordinates which must be valid at call time. No bound checks
   are performed, but the float coordinates must be valid (in the interval
   [0.0, 1.0]): */
void game_complete_color(game_color_t color);

/* Initialize predefined colors: */
void game_initialize_colors(void);

/* Some "predefined" colors, which become initialized after calling
   game_initialize_colors():  */
extern const game_color_t game_color_black;
extern const game_color_t game_color_white;
extern const game_color_t game_color_red;
extern const game_color_t game_color_green;
extern const game_color_t game_color_blue;
extern const game_color_t game_color_cyan;
extern const game_color_t game_color_magenta;
extern const game_color_t game_color_yellow;

/* Colors are also usable from Scheme: */
void game_define_color_smob(void);
SCM game_make_color_guile(SCM red, SCM green, SCM blue);
game_color_t game_color_smob_to_color(SCM color_smob);
SCM game_color_to_color_smob(game_color_t color);

#endif // #ifndef COLOR_H_
